pub struct EnsembleLearnerValidParams<P, R> {
pub ensemble_size: usize,
pub bootstrap_proportion: f64,
pub model_params: P,
pub rng: R,
}Fields
ensemble_size: usizeThe number of models in the ensemble
bootstrap_proportion: f64The proportion of the total number of training samples that should be given to each model for training
model_params: PThe model parameters for the base model
rng: RTrait Implementations
Sourceimpl<P: Clone, R: Clone> Clone for EnsembleLearnerValidParams<P, R>
impl<P: Clone, R: Clone> Clone for EnsembleLearnerValidParams<P, R>
Sourcefn clone(&self) -> EnsembleLearnerValidParams<P, R>
fn clone(&self) -> EnsembleLearnerValidParams<P, R>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D, T, P: Fit<Array2<D>, T::Owned, Error>, R: Rng + Clone> Fit<ArrayBase<OwnedRepr<D>, Dim<[usize; 2]>>, T, Error> for EnsembleLearnerValidParams<P, R>
impl<D, T, P: Fit<Array2<D>, T::Owned, Error>, R: Rng + Clone> Fit<ArrayBase<OwnedRepr<D>, Dim<[usize; 2]>>, T, Error> for EnsembleLearnerValidParams<P, R>
Sourceimpl<P: PartialEq, R: PartialEq> PartialEq for EnsembleLearnerValidParams<P, R>
impl<P: PartialEq, R: PartialEq> PartialEq for EnsembleLearnerValidParams<P, R>
Sourcefn eq(&self, other: &EnsembleLearnerValidParams<P, R>) -> bool
fn eq(&self, other: &EnsembleLearnerValidParams<P, R>) -> bool
Tests for
self and other values to be equal, and is used by ==.impl<P: Copy, R: Copy> Copy for EnsembleLearnerValidParams<P, R>
impl<P, R> StructuralPartialEq for EnsembleLearnerValidParams<P, R>