pub struct EnsembleLearnerParams<P, R>(/* private fields */);Expand description
A helper struct for building a set of Ensemble Learner hyper-parameters.
Implementations
Sourceimpl<P> EnsembleLearnerParams<P, ThreadRng>
impl<P> EnsembleLearnerParams<P, ThreadRng>
pub fn new(model_params: P) -> EnsembleLearnerParams<P, ThreadRng>
Sourceimpl<P, R: Rng + Clone> EnsembleLearnerParams<P, R>
impl<P, R: Rng + Clone> EnsembleLearnerParams<P, R>
pub fn new_fixed_rng(model_params: P, rng: R) -> EnsembleLearnerParams<P, R>
Sourcepub fn ensemble_size(self, size: usize) -> Self
pub fn ensemble_size(self, size: usize) -> Self
Specifies the number of models to fit in the ensemble.
Sourcepub fn bootstrap_proportion(self, proportion: f64) -> Self
pub fn bootstrap_proportion(self, proportion: f64) -> Self
Sets the proportion of the total number of training samples that should be given to each model for training
Note that the proportion should be in the interval (0, 1] in order to pass the
parameter validation check.
Sourcepub fn feature_proportion(self, proportion: f64) -> Self
pub fn feature_proportion(self, proportion: f64) -> Self
Sets the proportion of the total number of training features that should be given to each model for training
Note that the proportion should be in the interval (0, 1] in order to pass the
parameter validation check.